@@ -3,8 +3,8 @@ from random import choice
 from PyInquirer import style_from_dict, Token, prompt
 from PyInquirer import Validator, ValidationError
 import regex
-import ifinal
-import dummy
+from . import ifinal
+from . import dummy
 import re
 import sys
 
